
<template>
  <q-layout v-if="$store.state.login" view="LHh lpR lFf">

    <q-header elevated class="bg-primary text-white" height-hint="98">
      <q-toolbar>
        <q-btn dense flat round icon="menu" @click="toggleLeftDrawer" />

        <q-toolbar-title @click="openMainMenu">
          {{ $store.state.config?.company_name }}
        </q-toolbar-title>

        <q-btn dense flat round icon="menu" @click="toggleRightDrawer" />
      </q-toolbar>
    </q-header>

    <q-drawer show-if-above v-model="leftDrawerOpen" side="left" elevated>
      <div class="column items-center justify-center">
        <q-avatar size="120px">
          <img src="https://cdn.quasar.dev/img/avatar.png">
        </q-avatar>
        <h6 class="q-ma-none">User</h6>
      </div>
      <b-menu :menu="$store.getters.sideMenu" />
    </q-drawer>

    <q-drawer v-model="rightDrawerOpen" side="right" overlay behavior="desktop" bordered>
      <!-- drawer content -->
    </q-drawer>

    <q-page-container>
      <main-area :modules="$store.getters.sideMenu"></main-area>
    </q-page-container>

    <q-footer bordered class="bg-grey-8 text-white">
      <q-toolbar>
        <q-toolbar-title>
          <q-avatar>
            <img src="https://cdn.quasar.dev/logo-v2/svg/logo-mono-white.svg">
          </q-avatar>
          <div>Title</div>
        </q-toolbar-title>
      </q-toolbar>
    </q-footer>
    <q-dialog v-model="mainMenu.open">
      <q-card class="row justify-between">
        <q-card flat class="row q-pa-md bg-blue-10 text-white items-center justify-center col-3"
          v-for="menuItem, index in $store.getters.mainMenu" :key="index" style="border: 1px solid #ffffff">
          <div @click="$store.commit('activeMainMenu', { menuItem }); mainMenu.open = false">
            <q-icon name="user" />
            <div class="text-center ellipsis nowrap full-width">{{ menuItem.Title }}</div>
          </div>
        </q-card>

      </q-card>
    </q-dialog>
  </q-layout>

  <div class="row bg-red items-center justify-center" v-else>


    <login />

  </div>
</template>

<script>
import { ref } from 'vue'
import bMenu from 'components/menu/menu.vue'
import login from 'components/login.vue'
import mainArea from 'components/main-area.vue'
export default {
  setup() {
    const leftDrawerOpen = ref(false)
    const rightDrawerOpen = ref(false)
    const mainMenu = ref({ open: false })

    return {
      leftDrawerOpen,
      toggleLeftDrawer() {
        leftDrawerOpen.value = !leftDrawerOpen.value
      },

      rightDrawerOpen,
      toggleRightDrawer() {
        rightDrawerOpen.value = !rightDrawerOpen.value
      },

      mainMenu,
      openMainMenu() {
        mainMenu.value.open = true
      }
    }
  },
  components: {
    bMenu, login, mainArea
  },
  watch: {
    '$store.state.login': {
      handler(val) {
        if (val) {
          this.$store.dispatch('init')
        }
      },
      immediate: true
    }
  },
  created() {
    console.log('reinit')
    var self = this
    window.addEventListener('keyup', function (event) {
      if (event.key === 'F4') {
        event.preventDefault()
        self.openMainMenu()
      }
    });
  }

}
</script>
